package com.prolog.rdc.tms.service.basicConfigure;

import com.prolog.framework.core.pojo.Page;
import com.prolog.rdc.tms.model.dto.basicConfigure.MessageCountDTO;
import com.prolog.rdc.tms.model.dto.basicConfigure.SysAlertMessageQueryDTO;
import com.prolog.rdc.tms.model.vo.basicConfigure.*;

import java.util.List;

/**
 * 
 *
 * 首页-预警消息服务层
 *
 * @className :SysAlertMessageService
 * @author :fanzw
 * @creationTime :2022/01/18
 * @description :
 *
 * @modifier :fanzw
 * @modifyTime :2022/01/18
 * @reviseRemarks:
 *
 * @version :1.0.0
 *
 */
public interface SysAlertMessageService {

	/**
	 * 预警消息查询
	 * 
	 * @return
	 */
	Page<SysAlertMessageQueryDTO> listAlertMessageData(SysAlertMessageQueryVO sysAlertMessageQueryVO);

	/**
	 * 预警消息是否存在
	 *
	 * @return
	 */
	Boolean alertMessageIsExist(AlertMessageIsExistVO alertMessageIsExistVO);

	/**
	 * 预警消息新增
	 *
	 * @return
	 */
	void alertMessageAdd(List<AlertMessageAddVO> alertMessageAddVOs);

	/**
	 * 消息数量查询
	 * 
	 * @return
	 */
	MessageCountDTO countMessageData();

	/**
	 * 预警消息已读
	 * 
	 * @return
	 */
	void readAlertMessageData(List<SysAlertMessageReadVO> sysAlertMessageReadVOs);

	/**
	 * 预警消息处理
	 * 
	 * @return
	 */
	void handleAlertMessageData(List<SysAlertMessageHandleVO> sysAlertMessageHandleVOs);

}
